import click
from dataclasses import dataclass

from entail import TestEnv


@dataclass
class CliCtx:
    test_home: str


@click.group()
@click.option('--test_home', envvar='ENTAIL_BASE', default='entail_tests')
@click.pass_context
def cli(ctx, test_home):
    ctx.obj = CliCtx(test_home)


@cli.command()
@click.option('--name', default=None, help='Name of the test to run')
@click.option('--file', default=None, help='Path to the test file')
@click.option('--tag', default=None, help='tag of tests')
def run(name, file, tag):
    te = TestEnv()


@cli.command()
def init():
    pass


if __name__ == '__main__':
    cli()



import os

from pydantic import BaseModel


class RunConfig(BaseModel):
    bleu: bool = True
    rouge: bool = True
    meteor: bool = True
    entail: bool = True
    function: bool = True

    def disable_all(self):
        self.bleu = False
        self.rouge = False
        self.meteor = False
        self.entail = False
        self.function = False

        return self

    def enable_all(self):
        self.bleu = True
        self.rouge = True
        self.meteor = True
        self.entail = True
        self.function = True

        return self

    def enable_bleu(self):
        self.bleu = True
        return self

    def enable_rouge(self):
        self.rouge = True
        return self

    def enable_meteor(self):
        self.meteor = True
        return self

    def enable_entail(self):
        self.entail = True
        return self

    def enable_function(self):
        self.function = True
        return self

    def disable_bleu(self):
        self.bleu = False
        return self

    def disable_rouge(self):
        self.rouge = False
        return self

    def disable_meteor(self):
        self.meteor = False
        return self

    def disable_entail(self):
        self.entail = False
        return self

    def disable_function(self):
        self.function = False
        return self


def load_config_from_str(folder_path):
    with open(os.path.join(folder_path, 'entail_config.py')) as fd:
        code = fd.read()
        local_ctx = {}
        exec(code, globals(), local_ctx)
        entailment = local_ctx.get('entailment_model', None)
        if entailment is None:
            entailment = RunConfig()
        config = local_ctx.get('config', None)
        if config is None:
            config = RunConfig()
        handler = local_ctx.get['handler']

        return config, handler, entailment



from unittest import TestCase
import json

from entail.results import TestResults, TestResult, PRF1, FnMatchResult

from entail import TestCase as ETestCase, Fn, Message, DesiredOutput


class TestTestResults(TestCase):

    def test_summarize_fn_results(self):
        tr = TestResults(results=[

        ])
        self.fail()

    def test_summarize_entailment_results(self):
        tr = TestResults(results=[

        ])
        self.fail()

    def test_summarize_reference_results(self):
        self.fail()

    def test_list_fn_results(self):
        self.fail()

    def test_list_entailment_results(self):
        self.fail()

    def test_list_reference_results(self):
        self.fail()

    def test_list_concerns(self):
        self.fail()


class TestTestResult(TestCase):
    def test_compare_function_name_match(self):
        tr = TestResult(
            case=ETestCase()
        )
        tr.compare_function(Fn(name='f1', args={}), Fn(name='f1', args={}))
        self.assertTrue(tr.function_match.name_match)

        tr = TestResult(
            case=ETestCase()
        )
        tr.compare_function(Fn(name='f1', args={3: 2}), Fn(name='f1', args={}))
        self.assertTrue(tr.function_match.name_match)

        tr = TestResult(
            case=ETestCase()
        )
        tr.compare_function(Fn(name='f1', args={}), Fn(name='f12', args={}))
        self.assertFalse(tr.function_match.name_match)

    def test_compare_function_args_both_empty(self):
        tr = TestResult(
            case=ETestCase()
        )
        tr.compare_function(Fn(name='f1', args={}), Fn(name='f1', args={}))
        self.assertAlmostEqual(
            tr.function_match.args.precision, 1.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.precision, 1.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.f1, 1.0,
        )

    def test_compare_function_args_expect_empty(self):
        tr = TestResult(
            case=ETestCase(),
        )
        tr.compare_function(Fn(name='f1', args={}), Fn(name='f1', args={3: 1}))
        self.assertAlmostEqual(
            tr.function_match.args.precision, 0.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.recall, 0.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.f1, 0.0,
        )

    def test_compare_function_args_value_empty(self):
        tr = TestResult(
            case=ETestCase()
        )
        tr.compare_function(Fn(name='f1', args={'hello': 3}), Fn(name='f', args={}))
        self.assertAlmostEqual(
            tr.function_match.args.precision, 0.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.recall, 0.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.f1, 0.0,
        )

    def test_compare_function_args_both_non_empty(self):
        tr = TestResult(
            case=ETestCase(),
        )
        tr.compare_function(Fn(name='f1', args={'hello': 3}), Fn(name='f1', args={'hello': 4}))
        self.assertAlmostEqual(
            tr.function_match.args.precision, 0.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.recall, 0.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.f1, 0.0,
        )

        tr = TestResult(
            case=ETestCase(),
        )
        tr.compare_function(Fn(name='f1', args={'hello': 3}), Fn(name='f1', args={'hello': 3, 'world': 3}))
        self.assertAlmostEqual(
            tr.function_match.args.precision, 0.5,
        )
        self.assertAlmostEqual(
            tr.function_match.args.recall, 1.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.f1, 2 / 3.0,
        )
        tr = TestResult(
            case=ETestCase(),
        )
        tr.compare_function(Fn(name='f1', args={'hello': 3, 2: 3}), Fn(name='f1', args={'hello': 3}))
        self.assertAlmostEqual(
            tr.function_match.args.precision, 1.0,
        )
        self.assertAlmostEqual(
            tr.function_match.args.recall, 0.5,
        )
        self.assertAlmostEqual(
            tr.function_match.args.f1, 2 / 3.0,
        )

    def test_get_concern(self):
        tr = TestResult(
            case=ETestCase(
                output=DesiredOutput(
                    exact='world'
                ),
            ),
            reply=Message.from_assistant('hello'),
            exact_match=False,
        )

        c = tr.get_concern()
        self.assertEqual(c.reasons, [f'Response does not match: \n '
                                     f'Expected: world \n '
                                     f'Received: hello \n'])

        tr = TestResult(
            case=ETestCase(
                reply=Message.from_assistant(Fn(name='f1', args={})),
                output=DesiredOutput(
                    should_call_function=Fn(name='f1', args={'hello': '2'})
                ),
            ),
            reply=Message.from_assistant('hello'),
            function_match=FnMatchResult(name_match=True, args=PRF1(precision=0.0, recall=0.0, f1=0.0)),
        )

        c = tr.get_concern()
        self.assertEqual(c.reasons, [
            (f'Function Args does not match: \n '
             f'Expected: {json.dumps({"hello": "2"}, sort_keys=True)} \n '
             f'Received: {json.dumps({}, sort_keys=True)} \n')
        ])



import json
import sys
from dataclasses import dataclass
from typing import Optional

from pydantic import BaseModel, Field

from entail import RunConfig
from entail.core import RuleMatch, Fn, TestCase, Message


class PRF1(BaseModel):
    precision: float = 0.0
    recall: float = 0.0
    f1: float = 0.0

    def print(self, out=None, padding=0):
        if out is None:
            out = sys.stdout
        pads = ' ' * padding
        print(f'{pads}Precision  : {self.precision:.2f}', file=out)
        print(f'{pads}Recall     : {self.recall:.2f}', file=out)
        print(f'{pads}F1         : {self.f1:.2f}', file=out)

    def __eq__(self, other):
        return self.precision == other.precision and self.recall == other.recall and self.f1 == other.f1


class FnMatchResult(BaseModel):
    name_match: bool
    args: PRF1


class TestResult(BaseModel):
    case: TestCase
    reply: Optional[Message]

    # Referential testing
    exact_match: Optional[bool] = None
    bleu: Optional[float] = None
    rouge: Optional[PRF1] = None
    meteor: Optional[float] = None
    # Entail testing
    entails: list[RuleMatch] = Field(default_factory=list)
    # Function Call Testing
    function_match: Optional[FnMatchResult] = None

    is_empty: bool = False

    def compare_function(self, expected: Fn, value: Optional[Fn]):
        name_match = expected.name == value.name if value is not None else False

        if value is None:
            args_prf1 = PRF1(precision=0.0, recall=0.0, f1=0.0)
        else:
            if len(expected.args) == 0 and len(value.args) == 0:
                args_prf1 = PRF1(precision=1.0, recall=1.0, f1=1.0)
            else:
                rr_count = len(set(expected.args.items()).intersection(set(value.args.items())))
                p = rr_count * 1.0 / len(value.args) if len(value.args) > 0 else 0.0
                r = rr_count * 1.0 / len(expected.args) if len(expected.args) > 0 else 0.0
                f1 = 2 * p * r / (p + r) if (p + r) > 0 else 0.0
                args_prf1 = PRF1(precision=p, recall=r, f1=f1)
        self.function_match = FnMatchResult(name_match=name_match, args=args_prf1)

    def get_concern(self) -> 'TestingConcern':
        concern = TestingConcern()
        if self.exact_match is False:
            concern.append(f'Response does not match: \n '
                           f'Expected: {self.case.output.exact} \n '
                           f'Received: {self.reply.content} \n')

        if self.function_match is not None:
            if self.function_match.name_match is False:
                concern.append(f'Function Name does not match: \n '
                               f'Expected: {self.case.output.should_call_function.name} \n '
                               f'Received: {self.reply.fn.name} \n')
            if self.function_match.args.f1 != 1.0:
                concern.append(f'Function Args does not match: \n '
                               f'Expected: {json.dumps(self.case.output.should_call_function.args, sort_keys=True)} \n '
                               f'Received: {json.dumps(self.reply.fn.args, sort_keys=True)} \n')
        if self.entails:
            for rm in self.entails:
                if rm.score <= 0.5:
                    concern.append(f'Entailment Rule failed: \n '
                                   f'Rule: {rm.hypothesis} \n '
                                   f'Response: {self.reply.fn.args} \n')

        return concern


class TestingConcern(BaseModel):
    reasons: list[str] = Field(default_factory=list)

    def append(self, reason):
        self.reasons.append(reason)

    def is_valid(self):
        return len(self.reasons) > 0


class FnTestSummary(BaseModel):
    average: PRF1 = Field(default_factory=PRF1)
    name_matched: int = 0
    total: int = 0

    def print(self, out=None):
        if out is None:
            out = sys.stdout
        print(f"[Fn Tests]", file=out)
        print(f"Total                 :   {self.total}", file=out)
        print(f"Total Name Matches    :   {self.name_matched}", file=out)
        print(f"Total Name Mismatches :   {self.total - self.name_matched}", file=out)

        print(f"[Average Args Matches]", file=out)
        self.average.print(out=out, padding=4)


class EntailmentTestSummary(BaseModel):
    test_performed: int = 0
    average_score: float = 0.0

    def print(self, out=None):
        if out is None:
            out = sys.stdout
        print(f"Total Entailment Tests  : {self.test_performed}", file=out)
        print(f"Average Score           : {self.average_score:.2f}", file=out)


class ReferenceTestSummary(BaseModel):
    exact_math_positive: int = 0
    exact_math_negative: int = 0

    non_exact_test_count: int = 0
    bleu_average: Optional[float] = None
    rouge_average: Optional[PRF1] = None
    meteor_average: Optional[float] = None

    @property
    def exact_match_total(self):
        return self.exact_math_positive + self.exact_math_negative

    def print(self, out=None):
        if out is None:
            out = sys.stdout
        print(f"[Exact Matches Tests]", file=out)
        print(f"Positive           : {self.exact_math_positive}", file=out)
        print(f"Negative           : {self.exact_math_negative}", file=out)
        print(f"Total              : {self.exact_match_total}", file=out)
        print("", file=out)

        print(f"[Non Exact Matching Tests]", file=out)
        print(f"Total                   : {self.non_exact_test_count}", file=out)
        if self.bleu_average is not None:
            print(f"Average BLEU            : {self.bleu_average:.2f}", file=out)
        if self.meteor_average is not None:
            print(f"Average METEOR          : {self.meteor_average:.2f}", file=out)
        if self.rouge_average is not None:
            print(f"Average ROUGE", file=out)
            self.rouge_average.print(out, padding=4)


def mean_prf1(prf1s: list[PRF1]) -> PRF1:
    l = len(prf1s)
    p, r, f1 = 0.0, 0.0, 0.0
    if l == 0:
        return PRF1()
    for prf1 in prf1s:
        p += prf1.precision
        r += prf1.recall
        f1 += prf1.f1
    return PRF1(
        precision=p / l, recall=r / l, f1=f1 / l
    )


@dataclass
class TestResults:
    results: list['TestResult']
    config: RunConfig

    def summarize_fn_results(self) -> FnTestSummary:
        ret = FnTestSummary()
        ts = self.list_fn_results()
        ret.total = len(ts)
        ret.name_matched = len([t for t in ts if t.function_match.name_match])
        ret.average = mean_prf1([t.function_match.args for t in ts])
        return ret

    def summarize_entailment_results(self) -> EntailmentTestSummary:
        ret = EntailmentTestSummary()
        ts = self.list_entailment_results()
        scores = []
        for t in ts:
            ret.test_performed += 1
            for rm in t.entails:
                scores.append(rm.score)

        ret.average_score = len(scores) * 1.0 / len(scores)

        return ret

    def summarize_reference_results(self) -> ReferenceTestSummary:
        ret = ReferenceTestSummary()
        rs = self.list_reference_results()
        bleu = []
        rouge = []
        meteor = []
        for r in rs:
            if r.exact_match is not None:
                if r.exact_match is True:
                    ret.exact_math_positive += 1
                else:
                    ret.exact_math_negative += 1
            non_exact = False
            if self.config.bleu and r.bleu is not None:
                non_exact = True
                bleu.append(r.bleu)

            if self.config.meteor and r.meteor is not None:
                non_exact = True
                meteor.append(r.meteor)

            if self.config.rouge and r.rouge is not None:
                non_exact = True
                rouge.append(r.rouge)

            if non_exact:
                ret.non_exact_test_count += 1
        if self.config.meteor:
            ret.meteor_average = sum(meteor) * 1.0 / len(meteor) if len(meteor) > 0 else 0.0
        else:
            ret.meteor_average = None

        if self.config.bleu:
            ret.bleu_average = sum(bleu) * 1.0 / len(bleu) if len(bleu) > 0 else 0.0
        else:
            ret.bleu_average = None

        if self.config.rouge:
            ret.rouge_average = mean_prf1(rouge)
        else:
            ret.rouge_average = None

        return ret

    def list_fn_results(self):
        rs = []
        for r in self.results:
            if r.function_match is not None:
                rs.append(r)

        return rs

    def list_entailment_results(self):
        rs = []
        for r in self.results:
            if r.entails is not None and len(r.entails) > 0:
                rs.append(r)

        return rs

    def list_reference_results(self):
        rs = []
        for r in self.results:
            if r.case.output.exact is not None or r.case.output.example is not None:
                rs.append(r)
        return rs

    def print(self, out=None):
        if self.config.entail:
            self.summarize_entailment_results().print(out)
        r = self.summarize_reference_results()
        if r.exact_match_total > 0 or self.config.bleu or self.config.rouge or self.config.meteor:
            r.print(out)
        if self.config.function:
            self.summarize_fn_results().print(out)

    def list_concerns(self):
        for t in self.results:
            concern = t.get_concern()
            if concern.is_valid():
                yield t, concern

    def print_test_summary(self, out=None):
        if out is None:
            out = sys.stdout
        cs = list(self.list_concerns())
        if len(cs) == 0:
            print('OK', file=out)
        else:
            print('The following tests have concerns:', file=out)
            for idx, (t, c) in enumerate(cs):
                print(f"[{idx:03d}] Case name: {t.case.name}")
                print(f"Reply: {t.reply}")
                for reason in c.reasons:
                    print(reason, file=out)
                print('-------\n')



import abc
import os
from typing import Optional
from pydantic import BaseModel, Field
from enum import Enum


class ChatHandler(object):
    def __init__(self):
        pass

    @abc.abstractmethod
    def response(self, chat_history: list['Message'], external_information: Optional[dict] = None) -> 'Message':
        raise NotImplementedError()


class Should:
    @staticmethod
    def be_any_of(*args):
        for cond in args:
            pass


class Quantifier(str, Enum):
    any_of = 'any_of'
    all_of = 'all_of'
    none_of = 'none_of'


class Hypothesis(BaseModel):
    quantifier: Optional[Quantifier] = None
    children: Optional[list['Hypothesis']] = None
    value: Optional[str] = None

    @staticmethod
    def any_of(children: list['Hypothesis']):
        return Hypothesis(quantifier=Quantifier.any_of, children=children)

    @staticmethod
    def all_of(children: list['Hypothesis']):
        return Hypothesis(quantifier=Quantifier.all_of, children=children)

    @staticmethod
    def none_of(children: list['Hypothesis']):
        return Hypothesis(quantifier=Quantifier.none_of, children=children)

    @staticmethod
    def of(value: str):
        return Hypothesis(quantifier=None, value=value)

    def to_str(self):
        if self.quantifier == Quantifier.any_of:
            children = "\n".join([c.to_str() for c in self.children])
            return f"At least one of the following should be true: \n {children}"
        elif self.quantifier == Quantifier.all_of:
            children = "\n".join([c.to_str() for c in self.children])
            return f"All of the following should be true: \n {children}"
        elif self.quantifier == Quantifier.none_of:
            children = "\n".join([c.to_str() for c in self.children])
            return f"None of the following should be true: \n {children}"
        else:
            return self.value


class Role(str, Enum):
    system = 'system'
    user = 'user'
    assistant = 'assistant'
    function = 'function'


class Fn(BaseModel):
    name: str
    args: dict = Field(default_factory={})


class Message(BaseModel):
    role: Role
    content: Optional[str] = None
    fn: Optional[Fn] = None

    @staticmethod
    def from_user(value):
        return Message._create(Role.user, value)

    @staticmethod
    def from_assistant(value):
        return Message._create(Role.assistant, value)

    @staticmethod
    def _create(role, value):
        if isinstance(value, str):
            return Message(role=role, content=value)
        elif isinstance(value, Fn):
            return Message(role=role, fn=value)
        else:
            raise ValueError(f'Message value must be str or Fn')


class DesiredOutput(BaseModel):
    """
    A class describing the desired output of a chat message.

    When describing a desired text output, you should supply at least one of the example, exact, and should_be field
    When describing a desired function call output, you should supply should_call_function

    example: A reference response.
    should_be:
    should_call_function: what function should the response call
    """

    example: Optional[str] = None
    exact: Optional[str] = None
    should_be: Optional[list[Hypothesis]] = None
    should_call_function: Optional[Fn] = None


class TestCase(BaseModel):
    """
    A test case for chat model
    name: A optional name for this testcase, i.e. you can run a testcase by name
    description: A description of what is this test case testing.
    tags:  A list of tags for this testcase, i.e. you can run a list of testcases contains a certain tag
    external_info: a dict of external information should be supplied to the chat handler.
                   for example, in real application, this could be user info retrieved from database.
    history: chat history
    output: describe the desired output
    """
    name: Optional[str] = None
    description: Optional[str] = None
    tags: Optional[list[str]] = None
    external_info: Optional[dict] = None

    history: list[Message] = Field(default_factory=list)
    output: DesiredOutput = Field(default_factory=DesiredOutput)
    path: str = ''


class RuleMatch(BaseModel):
    hypothesis: Hypothesis
    score: float


def create_default_entailment():
    from entail.entailment.openai import GptEntailment
    return GptEntailment()


def create_testing_env(test_folder, testing=None, ):
    pass


def load_tests_from_str(content):
    local_ctx = {}
    exec(content, globals(), local_ctx)
    for k, v in local_ctx.items():
        if isinstance(v, TestCase):
            yield v


def load_testcases(folder_path):
    extensions = ['.entail.py']
    for root, dirs, files in os.walk(folder_path):
        for file in files:
            file_path = os.path.join(root, file)
            if any(file_path.endswith(ext) for ext in extensions):
                with open(file_path) as fd:
                    for cases in load_tests_from_str(fd.read()):
                        yield cases



from dataclasses import dataclass, field

from entail import ChatHandler, create_default_entailment, RunConfig, TestCase, utils, \
    RuleMatch, Quantifier, Hypothesis, Fn
from entail.results import TestResult, TestResults, PRF1
from entail.entailment import EntailmentModel


@dataclass
class NewTestEnv:
    handler: ChatHandler = None
    entailment: EntailmentModel = None
    config: RunConfig = None
    tests: list[TestCase] = field(default_factory=list)

    def create(self):

        if self.handler is None:
            raise ValueError('There is no ChatHandler to be tested, see .will_be_testing(your_handler)')

        if self.tests is None:
            raise ValueError('There is no testcases, using with_tests or with_test to add test cases')

        if self.config is None:
            self.config = RunConfig()

        if self.entailment is None:
            self.entailment = create_default_entailment()

        return TestEnv(
            self.handler,
            entailment=self.entailment,
            config=self.config,
            tests=self.tests,
        )

    def will_be_testing(self, handler: ChatHandler):
        self.handler = handler
        return self

    def with_tests(self, tests):
        for t in tests:
            self.tests.append(t)
        return self

    def with_test(self, t):
        self.tests.append(t)
        return self

    def using_config(self, config):
        self.config = config
        return self


@dataclass
class TestEnv:
    handler: ChatHandler
    entailment: EntailmentModel = field(default_factory=create_default_entailment)
    config: RunConfig = field(default_factory=RunConfig)
    tests: list[TestCase] = field(default_factory=list)

    def run_tests(self, tags=None, name=None):
        todo = []
        if tags is not None:
            for testcase in self.tests:
                match_tag = False
                for t in testcase.tags:
                    for mt in tags:
                        if t == mt:
                            match_tag = True
                            break
                todo.append(testcase)
        elif name is not None:
            for testcase in self.tests:
                if testcase.name == name:
                    todo.append(testcase)
        else:
            todo = [t for t in self.tests]

        results = []
        for t in todo:
            ret = self.run_test(t)
            results.append(ret)
        return TestResults(results=results, config=self.config)

    def run_test(self, testcase: TestCase) -> TestResult:
        reply = self.handler.response(testcase.history, external_information=testcase.external_info)
        result = TestResult(
            case=testcase,
            reply=reply,
        )

        if testcase.output.should_call_function:
            if self.config.function:
                result.compare_function(testcase.output.should_call_function, reply.fn)
        else:
            if testcase.output.exact:
                result.exact_match = testcase.output.exact == reply.content
            else:
                if testcase.output.example:
                    if self.config.bleu:
                        result.bleu = utils.bleu(testcase.output.example, reply.content)
                    if self.config.rouge:
                        result.rouge = PRF1(**utils.rouge(testcase.output.example, reply.content))
                    if self.config.meteor:
                        result.meteor = utils.meteor(testcase.output.example, reply.content)
                if testcase.output.should_be:
                    if self.config.entail:
                        for hypothesis in testcase.output.should_be:
                            score = test_hypothesis(hypothesis, self.entailment, reply.content)
                            result.entails.append(RuleMatch(hypothesis=hypothesis, score=score))

        return result


def test_hypothesis(hypothesis: Hypothesis, entailment: EntailmentModel, content: str):
    if hypothesis.quantifier == Quantifier.any_of:
        return max([test_hypothesis(x, entailment, content) for x in hypothesis.children])
    elif hypothesis.quantifier == Quantifier.all_of:
        return min([test_hypothesis(x, entailment, content) for x in hypothesis.children])
    elif hypothesis.quantifier == Quantifier.none_of:
        return max([1 - test_hypothesis(x, entailment, content) for x in hypothesis.children])
    elif hypothesis.quantifier is None:
        score = entailment.entail(content, hypothesis.value)
        return score



from nltk.translate.bleu_score import sentence_bleu, SmoothingFunction
from rouge_score import rouge_scorer
from nltk.translate.meteor_score import meteor_score
from nltk.tokenize import word_tokenize

cc = SmoothingFunction()


def bleu(reference, hypothesis):
    if isinstance(reference, str):
        reference = [word_tokenize(reference)]
    elif isinstance(reference, list):
        reference = [word_tokenize(r) for r in reference]

    hypothesis = word_tokenize(hypothesis)
    bleu_score = sentence_bleu(reference, hypothesis, smoothing_function=cc.method4)

    return bleu_score


rouge_scorer = rouge_scorer.RougeScorer(['rouge1', 'rougeL'], use_stemmer=True)


def rouge(reference, hypothesis):
    if isinstance(reference, str):
        return rouge_scorer.score(reference, hypothesis)
    elif isinstance(reference, list):
        return rouge_scorer.score_multi(reference, hypothesis)


def meteor(reference, hypothesis):
    r = word_tokenize(reference)
    h = word_tokenize(hypothesis)
    meteor_score_value = meteor_score([r], h)
    return meteor_score_value


def load_entailment_model(model_type, args=None):
    if args is None:
        args = {}
    if model_type == '':
        pass
    elif model_type == '':
        pass
    else:
        raise ValueError(f'Unknown entailment model type')



from distutils.core import setup

REQUIREMENTS = [
    'pydantic',
    'transformers',
    'nltk',
    'rouge-score',
]

setup(
    name='entail',
    version='0.0.3',
    description='Python Distribution Utilities',
    author='Hao Wu',
    author_email='haowu@dataset.sh',
    url='',
    packages=['entail'],
    install_requires=REQUIREMENTS
)
